<?php

/**
 * @file
 * This file contains functions to retrieve Fortissimmo data
 */

/**
 * Get all Fortissimmo active accounts
 */
function fortissimmo_get_accounts($reset = FALSE) {
  static $accounts;

  if (!$accounts || $reset) {
    $result = db_query("SELECT fortissimmo_bedrijfid, office, Account_name FROM {tblbedrijf_office} ORDER BY id ASC");
    while ($row = db_fetch_object($result)) {
      $accounts[$row->fortissimmo_bedrijfid] = $row->Account_name;
    }
  }

  return $accounts;
}

/**
 * Get the available transaction types
 */
function fortissimmo_get_transactions($accountid = NULL, $lang = NULL, $reset = FALSE) {
  static $transactions;

  global $language;
  if (!$lang) {
    $lang = $language->language;
  }
  if (!$accountid) {
    $accountid = variable_get('fortissimmo_default_account', 0);
  }

  if (!$transactions[$accountid][$lang] || $reset) {
    $result = db_query("SELECT value, name FROM {tbl_uzoekt_transaction} ORDER BY value ASC");
    while ($row = db_fetch_object($result)) {
      $transactions[$accountid][$lang][$row->value] = $row->name;
    }
  }

  return $transactions[$accountid][$lang];
}

/**
 * Get the property title for a given Fortissimmo property ID
 */
function fortissimmo_property_get_title($fortissimmo_id, $reset = FALSE) {
  static $titles;

  if (!$titles[$fortissimmo_id] || $reset) {
    $accountid = fortissimmo_property_get_accountid($fortissimmo_id);
    if (is_numeric($accountid) && $accountid > 0) {
      $result = db_query("SELECT title, reference FROM {tbl" . $accountid . "_pand} WHERE fortissimmo = %d", $fortissimmo_id);
      if ($row = db_fetch_object($result)) {
        if (!empty($row->title)) {
          $titles[$fortissimmo_id] = $row->title;
        }
        else {
          $titles[$fortissimmo_id] = $row->reference;
        }
        drupal_alter('fortissimmo_title', $titles[$fortissimmo_id]);
      }
    }
  }

  return $titles[$fortissimmo_id];
}

/**
 * Get the transaction type for a given Fortissimmo property ID
 */
function fortissimmo_property_get_transaction_type($fortissimmo_id, $reset = FALSE) {
  static $transaction_types;

  if (!$transaction_types[$fortissimmo_id] || $reset) {
    $accountid = fortissimmo_property_get_accountid($fortissimmo_id);
    if (is_numeric($accountid) && $accountid > 0) {
      $result = db_query("SELECT transaction, transactionValue FROM {tbl" . $accountid . "_pand} WHERE fortissimmo = %d", $fortissimmo_id);
      if ($row = db_fetch_object($result)) {
        drupal_alter('fortissimmo_transaction_type', $row);
        $transaction_types[$fortissimmo_id] = $row->transactionValue;
      }
    }
  }

  return $transaction_types[$fortissimmo_id];
}

/**
 * Get a list of available titles
 */
function fortissimmo_get_titles($accountid = NULL, $lang = NULL, $reset = FALSE) {
  static $titles;

  global $language;
  if (!$lang) {
    $lang = $language->language;
  }
  if (!$accountid) {
    $accountid = variable_get('fortissimmo_default_account', 0);
  }

  if (!$titles[$accountid][$lang] || $reset) {
    $result = db_query("SELECT value, name FROM {tbl_uzoekt_title} WHERE bedrijfid = %d AND lang = '%s'", $accountid, drupal_strtoupper($lang));
    while ($row = db_fetch_object($result)) {
      $titles[$accountid][$lang][$row->value] = $row->name;
    }
  }

  return $titles[$accountid][$lang];
}

/**
 * Get city_round values
 */
function fortissimmo_get_city_round() {
  return array(
    0 => ' -- ',
    1 => t('1 km'),
    2 => t('5 km'),
    3 => t('10 km'),
    4 => t('20 km'),
  );
}

/**
 * Get a list of available property types
 */
function fortissimmo_get_types($accountid = NULL, $lang = NULL, $reset = FALSE) {
  static $types;

  global $language;
  if (!$lang) {
    $lang = $language->language;
  }
  if (!$accountid) {
    $accountid = variable_get('fortissimmo_default_account', 0);
  }

  if (!$types[$accountid][$lang] || $reset) {
    $result = db_query("SELECT value, name FROM {tbl_uzoekt_type} ORDER  BY value ASC");
    while ($row = db_fetch_object($result)) {
      $types[$accountid][$lang][$row->value] = $row->name;
    }
  }

  return $types[$accountid][$lang];
}

/**
 * Save a request form submission
 */
function fortissimmo_save_request($data) {
  global $language;
  $accountid = variable_get('fortissimmo_default_account', 0);
  $mediaid = db_result(db_query("SELECT fortissimmo_mediaid FROM {tbl" . $accountid ."_pand} WHERE fortissimmo_bedrijfid = %d LIMIT 0, 1", $accountid));
  $contactid = fortissimmo_save_request_contact($data, $accountid, $mediaid);
  $requestid = fortissimmo_save_request_data($data, $accountid, $mediaid, $contactid);
  db_query("INSERT INTO {tblbedrijf_synchronisatie_request_contact} (bedrijfid, mediaid, contact) VALUES (%f, %f, %d)", $accountid, $mediaid, $contactid);
  db_query("INSERT INTO {tblbedrijf_synchronisatie_request} (bedrijfid, mediaid, requestid) VALUES (%f, %f, %d)", $accountid, $mediaid, $requestid);
}

/**
 * Save a contact to the database
 */
function fortissimmo_save_request_contact($data, $accountid, $mediaid) {
  global $language;
  // store data in table tbl<accountid>_uzoekt_contact
  db_query("INSERT INTO {tbl" . $accountid . "_uzoekt_contact} (fortissimmo, fortissimmo_mediaid, fortissimmo_bedrijfid, taal, email, title, lastname, firstname, address, zipcode, city, phone) VALUES (%d, %d, %d, '%s', '%s', %d, '%s', '%s', '%s', '%s', '%s', '%s')",
          NULL, // fortissimmo
          $mediaid, // fortissimmo_mediaid
          $accountid, // fortissimmo_bedrijfid
          drupal_strtoupper($language->language), // taal
          $data['email'], // email
          $$data['title'], // title
          $data['lastname'], // lastname
          $data['firstname'], // firstname
          $data['address'], // address
          $data['zipcode'], // zipcode
          $data['city'], // city
          $data['phone'] // phone
          );
  return db_last_insert_id("tbl" . $accountid . "_uzoekt_contact", 'id');
}

/**
 * Save a request to the database
 */
function fortissimmo_save_request_data($data, $accountid, $mediaid, $contactid) {
  $transactions = implode(';', array_filter($data['transaction']));
  $types = implode(';', array_filter($data['typeValue']));
  // store data in table tbl<accountid>_uzoekt_request
  db_query("INSERT INTO {tbl" . $accountid . "_uzoekt_request} (fortissimmo, fortissimmo_mediaid, fortissimmo_bedrijfid, contact, bedroom_max, bedroom_min, city_round, cityValue, name, price_max, price_min, transaction, type) VALUES (%d, %d, %d, %d, %d, %d, %d, '%s', '%s', '%s', '%s', '%s', '%s')",
          NULL, // fortissimmo
          $mediaid, // fortissimmo_mediaid
          $accountid, // fortissimmo_bedrijfid
          $contactid, // contact
          $data['bedroom_max'], // bedroom_max
          $data['bedroom_min'], // bedroom_min
          $data['city_round'], // city_round
          $data['cityValue'], // cityValue
          time(), // name
          $data['price_max'], // price_max
          $data['price_min'], // price_min
          $transactions, // transaction
          $types // type
          );
  return db_last_insert_id("tbl" . $accountid . "_uzoekt_request", 'id');
}