<?php

/**
 * @file
 * Provides function to integrate with Pathauto
 */

/**
 * Implementation of hook_token_values().
 */
function fortissimmo_token_values($type, $object = NULL, $options = array()) {
  if ($type == 'fortissimmo') {
    $tokens['title-raw'] = $object->title;
    $tokens['title'] = check_plain($object->title);
    $tokens['transaction-raw'] = $object->transaction;
    $tokens['transaction'] = check_plain($object->transaction);
    return $tokens;
  }
}

/**
 * Implementation of hook_token_list().
 */
function fortissimmo_token_list($type = 'all') {
  if ($type == 'fortissimmo' || $type == 'all') {
    $tokens['fortissimmo']['title-raw'] = t("The Fortissimmo property title (raw)");
    $tokens['fortissimmo']['title'] = t("The Fortissimmo property title");
    $tokens['fortissimmo']['transaction-raw'] = t("The Fortissimmo property transaction type (raw)");
    $tokens['fortissimmo']['transaction'] = t("The Fortissimmo property transaction type");
    return $tokens;
  }
}

/**
 * Implementation of hook_pathauto() for Fortissimmo aliases.
 */
function fortissimmo_pathauto($op) {
  switch ($op) {
    case 'settings':
      $settings = array();
      $settings['module'] = 'fortissimmo';
      $settings['token_type'] = 'fortissimmo';
      $settings['groupheader'] = t('Fortissimmo property path settings');
      $settings['patterndescr'] = t('Pattern for Fortissimmo property detail page paths');
      $settings['patterndefault'] = t('immo/[title]');
      $patterns = token_get_list('fortissimmo');
      foreach ($patterns as $type => $pattern_set) {
        if ($type != 'global') {
          foreach ($pattern_set as $pattern => $description) {
            $settings['placeholders']['['. $pattern .']'] = $description;
          }
        }
      }

      //$settings['bulkname'] = t('Bulk generate aliases for immo properties that are not aliased');
      //$settings['bulkdescr'] = t('Generate aliases for all existing immo property pages which do not already have aliases.');
      return (object) $settings;
    default:
      break;
  }
}

/**
 * Implementation of hook_path_alias_types().
 *
 * Specify the source pattern for paths of this type
 * Used primarily by the bulk delete form.
 */
function fortissimmo_path_alias_types() {
  return array('fortissimmo/property/' => t('Fortissimmo properties'));
}

/**
 * Create a pathauto alias for a Fortissimmo property
 */
function fortissimmo_create_path($fortissimmo_id, $op = 'insert') {
  if (module_exists('pathauto')) {
    module_load_include('inc', 'pathauto');
    // create a pseudo-object to store values attached to this Fortissimmo id
    $fortissimmo->title = fortissimmo_property_get_title($fortissimmo_id);
    $fortissimmo->transaction = fortissimmo_property_get_transaction_type($fortissimmo_id);
    $placeholders = pathauto_get_placeholders('fortissimmo', $fortissimmo);
    return pathauto_create_alias('fortissimmo', $op, $placeholders, 'fortissimmo/property/' . $fortissimmo_id, $fortissimmo_id);
  }
}