<?php

/**
 * @file
 * Fortissimmo pand pictures handler
 */

class views_handler_field_pand_picture_file extends views_handler_field {
  // @TODO: make an option select list for imagecache presets

  function init(&$view, $options) {
    parent::init($view, $options);
    if ($options['fortissimmo_title_as_alt'] == 1) {
      $this->additional_fields = array(
        'fortissimmo' => array('table' => $view->base_table, 'field' => 'fortissimmo'),
      );
    }

    // Retrieve Fortissimmo ID if we need to make this a link
    if ($options['fortissimmo_title_make_link'] == 1) {
      $this->additional_fields['fortissimmo'] = array('table' => $view->base_table, 'field' => 'fortissimmo');
    }
  }

  function option_definition() {
    $options = parent::option_definition();
    $options['imagecache_format'] = array('none' => 'none');

    return $options;
  }

  /**
   * Provide formatter option.
   */
  function options_form(&$form, &$form_state) {
    parent::options_form($form, $form_state);
    $options = $this->options;

    $init_array = array('none' => 'none');
    $imagecache_presets_values = imagecache_presets();
    $imagecache_presets = array();
    if ($imagecache_presets_values) {
      foreach ($imagecache_presets_values as $k => $v) {
        $presetname = $v['presetname'];
        $imagecache_presets[$presetname] = $presetname;
      }
    }
    $presets = array_merge($init_array, $imagecache_presets);

    $form['imagecache_format'] = array(
      '#title' => t('Imagecache preset'),
      '#type' => 'select',
      '#options' => $presets,
      '#required' => TRUE,
      '#default_value' => $options['imagecache_format'],
      '#weight' => 4,
    );

    $form['fortissimmo_title_make_link'] = array(
      '#type' => 'checkbox',
      '#title' => t('Link to property detail page'),
      '#default_value' => isset($options['fortissimmo_title_make_link']) ? $options['fortissimmo_title_make_link'] : 1,
    );

    $form['fortissimmo_use_lightbox'] = array(
      '#type' => 'checkbox',
      '#title' => t('Add lightbox rel attribute'),
      '#description' => t('Make sure to uncheck "Link to property detail page" above for this to work'),
      '#default_value' => isset($options['fortissimmo_use_lightbox']) ? $options['fortissimmo_use_lightbox'] : 0,
    );

    $form['fortissimmo_title_as_alt'] = array(
      '#type' => 'checkbox',
      '#title' => t('Use property title as alt/link text'),
      '#default_value' => isset($options['fortissimmo_title_as_alt']) ? $options['fortissimmo_title_as_alt'] : 1,
    );
  }


  function render($values) {
    $output = NULL;
    $options = $this->options;
    $make_link = $options['fortissimmo_title_make_link'];
    $title_as_alt = $options['fortissimmo_title_as_alt'];
    $preset_name = $options['imagecache_format'];
    $use_lightbox = $options['fortissimmo_use_lightbox'];
    $filename = $values->{$this->field_alias};
    if ($filename) {
      if ($title_as_alt) {
        $fortissimmo_id = $values->{$this->aliases['fortissimmo']};
        // @TODO: try to fix this with a JOIN on the base table instead...
        $pictures_table = $this->view->base_table;
        $pand_table = str_replace('_pictures', '', $pictures_table);
        $result = db_query("SELECT reference, title FROM {" . $pand_table . "} WHERE fortissimmo = %d", $fortissimmo_id);
        if ($pand_info = db_fetch_object($result)) {
          if (!empty($pand_info->title)) {
            $alt = $title = $pand_info->title;
          }
          else {
            $alt = $title = $pand_info->reference;
          }
        }
      }
      $file = fortissimmo_create_asset_url($filename, 'images');
      if ($preset_name == "none") {
        $output = $file; // @TODO
      }
      else {
        $output = theme('imagecache', $preset_name, $file, $alt, $title);
      }

      if (isset($this->aliases['fortissimmo']) && $make_link) {
        $fortissimmo_id = $values->{$this->aliases['fortissimmo']};
        $output = fortissimmo_generate_link($output, $fortissimmo_id, array('html' => TRUE));
      }
      elseif ($use_lightbox) {
        $output = l($output, $file, array('html' => TRUE, 'attributes' => array('rel' => 'lightshow[photos]')));
      }
    }
    return $output;
  }
}